@@ -11,7 +11,7 @@
 #include "proc_mem.h"
 #endif
 
-#define VERSION "2.1.2"
+#define VERSION "2.1.4"
 
 //#define DEBUGPRINT 1
 
@@ -29,24 +29,25 @@
 #define DBGPRINT5(a,b,c,d,e)
 #endif
 
-#define USAGE "StringTie v" VERSION " usage:\n\
- stringtie <input.bam ..> [-G <guide_gff>] [-l <label>] [-o <out_gtf>] [-p <cpus>]\n\
-  [-v] [-a <min_anchor_len>] [-m <min_tlen>] [-j <min_anchor_cov>] [-f <min_iso>]\n\
-  [-C <coverage_file_name>] [-c <min_bundle_cov>] [-g <bdist>] [-u] [-L] [-e]\n\
-  [--ptf <f_tab>] [-x <seqid,..>] [-A <gene_abund.out>] [-h] {-B | -b <dir_path>} \n\
+#define USAGE "StringTie v" VERSION " usage:\n\n\
+stringtie <in.bam ..> [-G <guide_gff>] [-l <prefix>] [-o <out.gtf>] [-p <cpus>]\n\
+ [-v] [-a <min_anchor_len>] [-m <min_len>] [-j <min_anchor_cov>] [-f <min_iso>]\n\
+ [-c <min_bundle_cov>] [-g <bdist>] [-u] [-L] [-e] [--viral] [-E <err_margin>]\n\
+ [--ptf <f_tab>] [-x <seqid,..>] [-A <gene_abund.out>] [-h] {-B|-b <dir_path>}\n\
 Assemble RNA-Seq alignments into potential transcripts.\n\
- Options:\n\
+Options:\n\
  --version : print just the version at stdout and exit\n\
- --conservative : conservative transcriptome assembly, same as -t -c 1.5 -f 0.05\n\
- --rf assume stranded library fr-firststrand\n\
- --fr assume stranded library fr-secondstrand\n\
+ --conservative : conservative transcript assembly, same as -t -c 1.5 -f 0.05\n\
+ --rf : assume stranded library fr-firststrand\n\
+ --fr : assume stranded library fr-secondstrand\n\
  -G reference annotation to use for guiding the assembly process (GTF/GFF3)\n\
- --ptf load point-features from a given 4 column feature file <f_tab>\n\
+ --ptf : load point-features from a given 4 column feature file <f_tab>\n\
  -o output path/file name for the assembled transcripts GTF (default: stdout)\n\
  -l name prefix for output transcripts (default: STRG)\n\
  -f minimum isoform fraction (default: 0.01)\n\
- -L use long reads settings (default:false)\n\
- -R if long reads are provided, just clean and collapse the reads but do not assemble\n\
+ -L long reads processing; also enforces -s 1.5 -g 0 (default:false)\n\
+ -R if long reads are provided, just clean and collapse the reads but\n\
+    do not assemble\n\
  -m minimum assembled transcript length (default: 200)\n\
  -a minimum anchor length for junctions (default: 10)\n\
  -j minimum junction coverage (default: 1)\n\
@@ -61,11 +62,15 @@ Assemble RNA-Seq alignments into potential transcripts.\n\
  -M fraction of bundle allowed to be covered by multi-hit reads (default:1)\n\
  -p number of threads (CPUs) to use (default: 1)\n\
  -A gene abundance estimation output file\n\
+ -E define window around possibly erroneous splice sites from long reads to\n\
+    look out for correct splice sites (default: 25)\n\
  -B enable output of Ballgown table files which will be created in the\n\
     same directory as the output GTF (requires -G, -o recommended)\n\
  -b enable output of Ballgown table files but these files will be \n\
     created under the directory path given as <dir_path>\n\
  -e only estimate the abundance of given reference transcripts (requires -G)\n\
+ --viral : only relevant for long reads from viral data where splice sites\n\
+    do not follow consensus (default:false)\n\
  -x do not assemble any transcripts on the given reference sequence(s)\n\
  -u no multi-mapping correction (default: correction enabled)\n\
  -h print this usage message and exit\n\
@@ -130,6 +135,7 @@ GStr tmpfname;
 GStr genefname;
 bool guided=false;
 bool trim=true;
+bool viral=false;
 bool eonly=false; // parameter -e ; for mergeMode includes estimated coverage sum in the merged transcripts
 bool longreads=false;
 bool rawreads=false;
@@ -146,6 +152,7 @@ int num_cpus=1;
 int mintranscriptlen=200; // minimum length for a transcript to be printed
 //int sensitivitylevel=1;
 uint junctionsupport=10; // anchor length for junction to be considered well supported <- consider shorter??
+uint sserror=25; // window arround splice sites that we use to generate consensus in case of long read data
 int junctionthr=1; // number of reads needed to support a particular junction
 float readthr=1;     // read coverage per bundle bp to accept it; // paper uses 3
 float singlethr=4.75;
@@ -270,8 +277,8 @@ int main(int argc, char* argv[]) {
 
  // == Process arguments.
  GArgs args(argc, argv,
-   "debug;help;version;conservative;keeptmp;rseq=;ptf=;bam;fr;rf;merge;"
-   "exclude=zEihvteuLRx:n:j:s:D:G:C:S:l:m:o:a:j:c:f:p:g:P:M:Bb:A:F:T:");
+   "debug;help;version;viral;conservative;keeptmp;rseq=;ptf=;bam;fr;rf;merge;"
+   "exclude=zihvteuLRx:n:j:s:D:G:C:S:l:m:o:a:j:c:f:p:g:P:M:Bb:A:E:F:T:");
  args.printError(USAGE, true);
 
  processOptions(args);
@@ -285,7 +292,7 @@ int main(int argc, char* argv[]) {
  GPVec<RC_Feature> guides_RC_exons(true); //raw count data for all guide exons
  GPVec<RC_Feature> guides_RC_introns(true);//raw count data for all guide introns
 
- GVec<int> alncounts(30,0); //keep track of the number of read alignments per chromosome [gseq_id]
+ GVec<int> alncounts(30); //keep track of the number of read alignments per chromosome [gseq_id]
 
  int bamcount=bamreader.start(); //setup and open input files
 #ifndef GFF_DEBUG
@@ -474,7 +481,6 @@ if (tstackSize<DEF_TSTACK_SIZE) defStackSize=DEF_TSTACK_SIZE;
 					 brec->name(), brec->start, brec->mapped_len);
 			 continue;
 		 }
-
 		 refseqName=brec->refName();
 		 xstrand=brec->spliceStrand(); // tagged strand gets priority
 		 if(xstrand=='.' && (fr_strand || rf_strand)) { // set strand if stranded library
@@ -517,12 +523,15 @@ if (tstackSize<DEF_TSTACK_SIZE) defStackSize=DEF_TSTACK_SIZE;
 			 }
 
 			 if (alncounts.Count()<=gseq_id) {
-				 alncounts.Resize(gseq_id+1, 0);
+				 alncounts.Resize(gseq_id+1);
 			 }
-			 else if (alncounts[gseq_id]>0) GError(ERR_BAM_SORT);
+			 else if (alncounts[gseq_id]>0)
+			           GError("%s\nAlignments (%d) already found for %s !\n",
+			             ERR_BAM_SORT, alncounts[gseq_id], refseqName);
 			 prev_pos=0;
 		 }
-		 if (pos<prev_pos) GError(ERR_BAM_SORT);
+		 if (pos<prev_pos) GError("%s\nread %s (start %d) found at position %d on %s when prev_pos=%d\n",
+		       ERR_BAM_SORT, brec->name(), brec->start,  pos, refseqName, prev_pos);
 		 prev_pos=pos;
 		 if (skipGseq) continue;
 		 alncounts[gseq_id]++;
@@ -530,7 +539,8 @@ if (tstackSize<DEF_TSTACK_SIZE) defStackSize=DEF_TSTACK_SIZE;
 		 if (nh==0) nh=1;
 		 hi=brec->tag_int("HI");
 		 if (mergeMode) {
-		    tinfo=new TAlnInfo(brec->name(), brec->tag_int("ZF"));
+		    //tinfo=new TAlnInfo(brec->name(), brec->tag_int("ZF"));
+			 tinfo=new TAlnInfo(brec->name(), brec->uval);
 		    GStr score(brec->tag_str("ZS"));
 		    if (!score.is_empty()) {
 		      GStr srest=score.split('|');
@@ -759,9 +769,7 @@ if (tstackSize<DEF_TSTACK_SIZE) defStackSize=DEF_TSTACK_SIZE;
     	 //GMessage("%s\t%c\t%d\thi=%d\n",brec->name(), xstrand, alndata.strand,hi);
     	 //countFragment(*bundle, *brec, hi,nh); // we count this in build_graphs to only include mapped fragments that we consider correctly mapped
     	 //fprintf(stderr,"fragno=%d fraglen=%lu\n",bundle->num_fragments,bundle->frag_len);if(bundle->num_fragments==100) exit(0);
-    	 //if (!ballgown || ref_overlap)
     	   processRead(currentstart, currentend, *bundle, hashread, alndata);
-			  // *brec, strand, nh, hi);
      }
  } //for each read alignment
 
@@ -941,6 +949,10 @@ void processOptions(GArgs& args) {
 	}
 
 
+	if (args.getOpt("viral")) {
+		viral=true;
+	}
+
 	 longreads=(args.getOpt('L')!=NULL);
 	 if(longreads) {
 		 bundledist=0;
@@ -970,6 +982,9 @@ void processOptions(GArgs& args) {
 	 debugMode=(args.getOpt("debug")!=NULL || args.getOpt('D')!=NULL);
 	 forceBAM=(args.getOpt("bam")!=NULL); //assume the stdin stream is BAM instead of text SAM
 	 mergeMode=(args.getOpt("merge")!=NULL);
+	 if(mergeMode) {
+		 longreads=false; // these are not longreads
+	 }
 	 keepTempFiles=(args.getOpt("keeptmp")!=NULL);
 	 //adaptive=!(args.getOpt('d')!=NULL);
 	 verbose=(args.getOpt('v')!=NULL);
@@ -1048,6 +1063,8 @@ void processOptions(GArgs& args) {
 	 s=args.getOpt('j');
 	 if (!s.is_empty()) junctionthr=s.asInt();
 
+	 s=args.getOpt('E');
+	 if (!s.is_empty()) sserror=s.asInt();
 
 	 rawreads=(args.getOpt('R')!=NULL);
 	 if(rawreads) {
@@ -1134,7 +1151,7 @@ void processOptions(GArgs& args) {
 	             ptff.chars());
 	 }
 
-	 enableNames=(args.getOpt('E')!=NULL);
+	 //enableNames=(args.getOpt('E')!=NULL);
 
 	 retained_intron=(args.getOpt('i')!=NULL);
 
